@@ -19,7 +19,12 @@ def env(**kwargs):
 
 
 class raw_env(AECEnv):
-    metadata = {'render.modes': ['human'], "name": "backgammon_v3"}
+    metadata = {
+        "render.modes": ["human"],
+        "name": "backgammon_v3",
+        "is_parallelizable": False,
+        "video.frames_per_second": 2,
+    }
 
     def __init__(self):
         super().__init__()
@@ -144,7 +149,6 @@ class raw_env(AECEnv):
         assert mode in ['human'], print(mode)
         if mode == 'human':
             self.game.render()
-            return True
 
     def close(self):
         pass
