@@ -8,8 +8,6 @@ from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
 from pettingzoo.utils.agent_selector import agent_selector
 
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
-
 
 def get_image(path):
     from os import path as os_path
@@ -31,7 +29,12 @@ def env():
 
 
 class raw_env(AECEnv):
-    metadata = {'render.modes': ['human', "rgb_array"], "name": "connect_four_v3"}
+    metadata = {
+        "render.modes": ["human", "rgb_array"],
+        "name": "connect_four_v3",
+        "is_parallelizable": False,
+        "video.frames_per_second": 2,
+    }
 
     def __init__(self):
         super().__init__()
