@@ -14,8 +14,6 @@ from pettingzoo.utils.agent_selector import agent_selector
 
 from .rlcard_base import RLCardBase
 
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
-
 
 def get_image(path):
     from os import path as os_path
@@ -41,7 +39,12 @@ def env(**kwargs):
 
 class raw_env(RLCardBase):
 
-    metadata = {'render.modes': ['human', 'rgb_array'], "name": "texas_holdem_v4"}
+    metadata = {
+        "render.modes": ["human", "rgb_array"],
+        "name": "texas_holdem_v4",
+        "is_parallelizable": False,
+        "video.frames_per_second": 1,
+    }
 
     def __init__(self, num_players=2):
         super().__init__("limit-holdem", num_players, (72,))
