@@ -23,7 +23,12 @@ def env(**kwargs):
 
 class raw_env(RLCardBase):
 
-    metadata = {'render.modes': ['human'], 'name': 'uno_v4'}
+    metadata = {
+        "render.modes": ["human"],
+        "name": "uno_v4",
+        "is_parallelizable": False,
+        "video.frames_per_second": 2,
+    }
 
     def __init__(self, opponents_hand_visible=False):
         self._opponents_hand_visible = opponents_hand_visible
