@@ -9,7 +9,7 @@ from gym.utils import EzPickle
 from pettingzoo import AECEnv
 from pettingzoo.magent.render import Renderer
 from pettingzoo.utils import agent_selector, wrappers
-from pettingzoo.utils.conversions import from_parallel_wrapper, parallel_wrapper_fn
+from pettingzoo.utils.conversions import parallel_to_aec_wrapper, parallel_wrapper_fn
 
 from .battle_v3 import KILL_REWARD, get_config
 from .magent_env import magent_parallel_env, make_env
@@ -27,14 +27,18 @@ def parallel_env(map_size=default_map_size, max_cycles=max_cycles_default, minim
 
 
 def raw_env(map_size=default_map_size, max_cycles=max_cycles_default, minimap_mode=minimap_mode_default, extra_features=False, **reward_args):
-    return from_parallel_wrapper(parallel_env(map_size, max_cycles, minimap_mode, extra_features, **reward_args))
+    return parallel_to_aec_wrapper(parallel_env(map_size, max_cycles, minimap_mode, extra_features, **reward_args))
 
 
 env = make_env(raw_env)
 
 
 class _parallel_env(magent_parallel_env, EzPickle):
-    metadata = {'render.modes': ['human', 'rgb_array'], 'name': "battlefield_v3"}
+    metadata = {
+        "render.modes": ["human", "rgb_array"],
+        'name': "battlefield_v3",
+        "video.frames_per_second": 5,
+        }
 
     def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
         EzPickle.__init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features)
