@@ -9,7 +9,7 @@ from gym.utils import EzPickle
 from pettingzoo import AECEnv
 from pettingzoo.magent.render import Renderer
 from pettingzoo.utils import agent_selector
-from pettingzoo.utils.conversions import from_parallel_wrapper, parallel_wrapper_fn
+from pettingzoo.utils.conversions import parallel_to_aec_wrapper, parallel_wrapper_fn
 
 from .magent_env import magent_parallel_env, make_env
 
@@ -26,7 +26,7 @@ def parallel_env(map_size=default_map_size, max_cycles=max_cycles_default, minim
 
 
 def raw_env(map_size=default_map_size, max_cycles=max_cycles_default, minimap_mode=minimap_mode_default, extra_features=False, **env_args):
-    return from_parallel_wrapper(parallel_env(map_size, max_cycles, minimap_mode, extra_features, **env_args))
+    return parallel_to_aec_wrapper(parallel_env(map_size, max_cycles, minimap_mode, extra_features, **env_args))
 
 
 env = make_env(raw_env)
@@ -79,8 +79,11 @@ def get_config(map_size, minimap_mode, tiger_step_recover, deer_attacked):
 
 
 class _parallel_env(magent_parallel_env, EzPickle):
-    metadata = {'render.modes': ['human', 'rgb_array'], 'name': "tiger_deer_v3"}
-
+    metadata = {
+        "render.modes": ["human", "rgb_array"],
+        'name': "tiger_deer_v3",
+        "video.frames_per_second": 5,
+        }
     def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
         EzPickle.__init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features)
         assert map_size >= 10, "size of map must be at least 10"
