@@ -9,8 +9,7 @@ from scipy.spatial import distance as ssd
 
 from .._utils import Agent
 
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
-
+FPS = 15
 
 class Archea(Agent):
 
@@ -121,7 +120,7 @@ class Archea(Agent):
 class MAWaterWorld():
 
     def __init__(self, n_pursuers=5, n_evaders=5, n_poison=10, n_coop=2, n_sensors=30, sensor_range=0.2,
-                 radius=0.015, obstacle_radius=0.2, obstacle_coord=np.array([0.5, 0.5]),
+                 radius=0.015, obstacle_radius=0.2, obstacle_coord=(0.5, 0.5),
                  pursuer_max_accel=0.01, evader_speed=0.01, poison_speed=0.01, poison_reward=-1.0,
                  food_reward=10.0, encounter_reward=0.01, thrust_penalty=-0.5, local_ratio=1.0,
                  speed_features=True, max_cycles=500):
@@ -196,7 +195,7 @@ class MAWaterWorld():
         self.renderOn = False
         self.pixel_scale = 30 * 25
 
-        self.cycle_time = 1.0
+        self.cycle_time = 1.0 * 15. / FPS
         self.frames = 0
         self.reset()
 
