@@ -10,7 +10,7 @@ class AssertOutOfBoundsWrapper(BaseWrapper):
     '''
     def __init__(self, env):
         super().__init__(env)
-        assert all(isinstance(space, Discrete) for space in getattr(self, 'action_spaces', {}).values()), "should only use AssertOutOfBoundsWrapper for Discrete spaces"
+        assert all(isinstance(self.action_space(agent), Discrete) for agent in getattr(self, 'possible_agents', [])), "should only use AssertOutOfBoundsWrapper for Discrete spaces"
 
     def step(self, action):
         assert (action is None and self.dones[self.agent_selection]) or self.action_space(self.agent_selection).contains(action), "action is not in action space"
