@@ -36,19 +36,19 @@ parameterized_envs = [
     (texas_holdem_no_limit_v6.env, dict(num_players=3)),
     (texas_holdem_no_limit_v6.env, dict(num_players=4)),
 
-    (knights_archers_zombies_v7.env, dict(spawn_rate=50)),
-    (knights_archers_zombies_v7.env, dict(num_knights=4, num_archers=5)),
-    (knights_archers_zombies_v7.env, dict(killable_knights=True, killable_archers=True)),
-    (knights_archers_zombies_v7.env, dict(killable_knights=False, killable_archers=False)),
-    (knights_archers_zombies_v7.env, dict(line_death=False)),
-    (knights_archers_zombies_v7.env, dict(pad_observation=False)),
-    (knights_archers_zombies_v7.env, dict(max_cycles=100)),
+    (knights_archers_zombies_v8.env, dict(spawn_rate=50)),
+    (knights_archers_zombies_v8.env, dict(num_knights=4, num_archers=5)),
+    (knights_archers_zombies_v8.env, dict(killable_knights=True, killable_archers=True)),
+    (knights_archers_zombies_v8.env, dict(killable_knights=False, killable_archers=False)),
+    (knights_archers_zombies_v8.env, dict(line_death=False)),
+    (knights_archers_zombies_v8.env, dict(pad_observation=False)),
+    (knights_archers_zombies_v8.env, dict(max_cycles=100)),
 
-    (pistonball_v5.env, dict(continuous=True)),
-    (pistonball_v5.env, dict(n_pistons=30)),
-    (pistonball_v5.env, dict(continuous=False)),
-    (pistonball_v5.env, dict(random_drop=True, random_rotate=True)),
-    (pistonball_v5.env, dict(random_drop=False, random_rotate=False)),
+    (pistonball_v6.env, dict(continuous=True)),
+    (pistonball_v6.env, dict(n_pistons=30)),
+    (pistonball_v6.env, dict(continuous=False)),
+    (pistonball_v6.env, dict(random_drop=True, random_rotate=True)),
+    (pistonball_v6.env, dict(random_drop=False, random_rotate=False)),
 
     (prison_v3.env, dict(continuous=True)),
     (prison_v3.env, dict(continuous=False)),
@@ -110,10 +110,10 @@ parameterized_envs = [
     (simple_world_comm_v2.env, dict(num_good=5, num_adversaries=10, num_obstacles=4, num_food=3, continuous_actions=True)),
     (simple_world_comm_v2.env, dict(num_good=1, num_adversaries=1, num_obstacles=1, num_food=1, continuous_actions=True)),
 
-    (multiwalker_v7.env, dict(n_walkers=10)),
-    (multiwalker_v7.env, dict(local_ratio=0.5)),
-    (multiwalker_v7.env, dict(terminate_on_fall=False)),
-    (multiwalker_v7.env, dict(terminate_on_fall=False, remove_on_fall=False)),
+    (multiwalker_v8.env, dict(n_walkers=10)),
+    (multiwalker_v8.env, dict(shared_reward=False)),
+    (multiwalker_v8.env, dict(terminate_on_fall=False)),
+    (multiwalker_v8.env, dict(terminate_on_fall=False, remove_on_fall=False)),
 
     (pursuit_v4.env, dict(x_size=8, y_size=19)),
     (pursuit_v4.env, dict(shared_reward=True)),
